@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2016 Andriy Grytsenko <andrej@rep.kiev.ua>
+ * Copyright (C) 2016-2021 Andriy Grytsenko <andrej@rep.kiev.ua>
  *
  * This file is a part of LXHotkey project.
  *
@@ -181,7 +181,7 @@ static void on_about(GtkAction *act, PluginData *data)
     gtk_about_dialog_set_program_name(about, "LXHotkey"); //FIXME: translated?
     gtk_about_dialog_set_logo_icon_name(about, LXHOTKEY_ICON);
 
-    gtk_about_dialog_set_copyright(about, _("Copyright (C) 2016"));
+    gtk_about_dialog_set_copyright(about, _("Copyright (C) 2016-2021"));
     gtk_about_dialog_set_comments(about, _( "Keyboard shortcuts configurator"));
     gtk_about_dialog_set_license(about, "This program is free software; you can redistribute it and/or\n"
                                         "modify it under the terms of the GNU General Public License\n"
@@ -341,6 +341,7 @@ static void module_gtk_run(const gchar *wm, const LXHotkeyPluginInit *cb,
     GtkWidget *win, *menubar;
     GtkToolbar *toolbar;
     GtkBox *vbox;
+    GtkScrolledWindow *scrwin;
     PluginData data;
 
     if (!inited)
@@ -371,8 +372,16 @@ static void module_gtk_run(const gchar *wm, const LXHotkeyPluginInit *cb,
     data.cb = cb;
     data.config = config;
 
+#if GTK_CHECK_VERSION(3, 0, 0)
+    if (gtk_get_major_version() > 3 || gtk_get_minor_version() >= 2)
+        data.use_primary = TRUE;
+#else
+    if (gtk_check_version(2, 24, 0) == NULL)
+        data.use_primary = TRUE;
+#endif
+
     win = gtk_window_new(GTK_WINDOW_TOPLEVEL);
-    gtk_window_set_default_size(GTK_WINDOW(win), 400, 300);
+    gtk_window_set_default_size(GTK_WINDOW(win), 800, 480);
     gtk_window_set_icon_name(GTK_WINDOW(win), LXHOTKEY_ICON);
     g_signal_connect(win, "unmap", G_CALLBACK(gtk_main_quit), NULL);
 
@@ -417,7 +426,13 @@ static void module_gtk_run(const gchar *wm, const LXHotkeyPluginInit *cb,
     g_signal_connect_after(data.notebook, "switch-page",
                            G_CALLBACK(on_notebook_switch_page), &data);
 
-    gtk_box_pack_start(vbox, GTK_WIDGET(data.notebook), TRUE, TRUE, 0);
+    /* notebook should be in a scrolled window if there is no enough space */
+    scrwin = (GtkScrolledWindow *)gtk_scrolled_window_new(NULL, NULL);
+    gtk_scrolled_window_add_with_viewport(scrwin, GTK_WIDGET(data.notebook));
+    gtk_scrolled_window_set_policy(scrwin, GTK_POLICY_AUTOMATIC,
+                                   GTK_POLICY_AUTOMATIC);
+
+    gtk_box_pack_start(vbox, GTK_WIDGET(scrwin), TRUE, TRUE, 0);
 
     /* setup notebook */
     if (cb->get_wm_keys)
